@@ -11,8 +11,8 @@
 
 namespace Symfony\Component\Config\Tests\Definition\Builder;
 
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
-use Symfony\Bridge\PhpUnit\ExpectDeprecationTrait;
 use Symfony\Component\Config\Definition\Builder\ArrayNodeDefinition;
 use Symfony\Component\Config\Definition\Builder\BooleanNodeDefinition;
 use Symfony\Component\Config\Definition\Builder\NodeDefinition;
@@ -24,8 +24,6 @@ use Symfony\Component\Config\Definition\PrototypedArrayNode;
 
 class ArrayNodeDefinitionTest extends TestCase
 {
-    use ExpectDeprecationTrait;
-
     public function testAppendingSomeNode()
     {
         $parent = new ArrayNodeDefinition('root');
@@ -42,9 +40,7 @@ class ArrayNodeDefinitionTest extends TestCase
         $this->assertContains($child, $this->getField($parent, 'children'));
     }
 
-    /**
-     * @dataProvider providePrototypeNodeSpecificCalls
-     */
+    #[DataProvider('providePrototypeNodeSpecificCalls')]
     public function testPrototypeNodeSpecificOption(string $method, array $args)
     {
         $this->expectException(InvalidDefinitionException::class);
@@ -100,12 +96,8 @@ class ArrayNodeDefinitionTest extends TestCase
         $this->assertEquals([[]], $tree->getDefaultValue());
     }
 
-    /**
-     * @param int|array|string|null $args
-     *
-     * @dataProvider providePrototypedArrayNodeDefaults
-     */
-    public function testPrototypedArrayNodeDefault($args, bool $shouldThrowWhenUsingAttrAsKey, bool $shouldThrowWhenNotUsingAttrAsKey, array $defaults)
+    #[DataProvider('providePrototypedArrayNodeDefaults')]
+    public function testPrototypedArrayNodeDefault(int|array|string|null $args, bool $shouldThrowWhenUsingAttrAsKey, bool $shouldThrowWhenNotUsingAttrAsKey, array $defaults)
     {
         $node = new ArrayNodeDefinition('root');
         $node
@@ -175,9 +167,7 @@ class ArrayNodeDefinitionTest extends TestCase
         $this->assertEquals(['enabled' => false, 'foo' => 'bar'], $node->getNode()->getDefaultValue());
     }
 
-    /**
-     * @dataProvider getEnableableNodeFixtures
-     */
+    #[DataProvider('getEnableableNodeFixtures')]
     public function testTrueEnableEnabledNode(array $expected, array $config, string $message)
     {
         $processor = new Processor();
@@ -195,6 +185,16 @@ class ArrayNodeDefinitionTest extends TestCase
         );
     }
 
+    public function testCanBeEnabledWithInfo()
+    {
+        $node = new ArrayNodeDefinition('root');
+        $node->canBeEnabled('Some info about disabling this node');
+
+        $child = $this->getField($node, 'children')['enabled'];
+
+        $this->assertEquals('Some info about disabling this node', $this->getField($child, 'attributes')['info']);
+    }
+
     public function testCanBeDisabled()
     {
         $node = new ArrayNodeDefinition('root');
@@ -213,6 +213,16 @@ class ArrayNodeDefinitionTest extends TestCase
         $this->assertTrue($this->getField($enabledNode, 'defaultValue'));
     }
 
+    public function testCanBeDisabledWithInfo()
+    {
+        $node = new ArrayNodeDefinition('root');
+        $node->canBeDisabled('Some info about disabling this node');
+
+        $child = $this->getField($node, 'children')['enabled'];
+
+        $this->assertEquals('Some info about disabling this node', $this->getField($child, 'attributes')['info']);
+    }
+
     public function testIgnoreExtraKeys()
     {
         $node = new ArrayNodeDefinition('root');
@@ -244,9 +254,7 @@ class ArrayNodeDefinitionTest extends TestCase
             ->children()
                 ->scalarNode('value')
                     ->beforeNormalization()
-                        ->ifTrue(function ($value) {
-                            return empty($value);
-                        })
+                        ->ifTrue(fn ($value) => !$value)
                         ->thenUnset()
                     ->end()
                 ->end()
@@ -274,6 +282,12 @@ class ArrayNodeDefinitionTest extends TestCase
         $this->assertEquals($node->prototype('boolean'), $node->booleanPrototype());
     }
 
+    public function testPrototypeString()
+    {
+        $node = new ArrayNodeDefinition('root');
+        $this->assertEquals($node->prototype('string'), $node->stringPrototype());
+    }
+
     public function testPrototypeInteger()
     {
         $node = new ArrayNodeDefinition('root');
@@ -292,6 +306,31 @@ class ArrayNodeDefinitionTest extends TestCase
         $this->assertEquals($node->prototype('array'), $node->arrayPrototype());
     }
 
+    public function testPrototypedArrayAllowsNullDefault()
+    {
+        $node = new ArrayNodeDefinition('root');
+        $node
+            ->defaultValue(null)
+            ->prototype('array')
+        ;
+
+        $tree = $node->getNode();
+        $this->assertNull($tree->getDefaultValue());
+    }
+
+    public function testPrototypedArrayRejectsNonArrayDefaultValue()
+    {
+        $node = new ArrayNodeDefinition('root');
+        $node
+            ->defaultValue('not-an-array')
+            ->prototype('array')
+        ;
+
+        $this->expectException(\InvalidArgumentException::class);
+        $this->expectExceptionMessage('the default value of an array node has to be an array or null');
+        $node->getNode();
+    }
+
     public function testPrototypeEnum()
     {
         $node = new ArrayNodeDefinition('root');
@@ -310,6 +349,53 @@ class ArrayNodeDefinitionTest extends TestCase
         ];
     }
 
+    #[DataProvider('provideEnabledStateAfterMerging')]
+    public function testEnabledStateIsPreservedAcrossMergedConfigs(array $firstConfig, array $expected, callable $nodeFactory)
+    {
+        $processor = new Processor();
+        $node = $nodeFactory();
+
+        $this->assertSame(
+            $expected,
+            $processor->process($node->getNode(), [
+                $firstConfig,
+                ['foo' => 'baz'],
+            ])
+        );
+    }
+
+    public static function provideEnabledStateAfterMerging(): array
+    {
+        $factory = static function (callable $builder) {
+            $node = new ArrayNodeDefinition('root');
+            $builder($node)
+                ->children()
+                    ->scalarNode('foo')->defaultValue('bar')->end()
+                ->end()
+            ;
+
+            return $node;
+        };
+
+        return [
+            'canBeEnabled keeps explicit true' => [
+                ['enabled' => true],
+                ['enabled' => true, 'foo' => 'baz'],
+                static fn () => $factory(static fn ($node) => $node->canBeEnabled()),
+            ],
+            'canBeDisabled keeps explicit false' => [
+                ['enabled' => false],
+                ['enabled' => false, 'foo' => 'baz'],
+                static fn () => $factory(static fn ($node) => $node->canBeDisabled()),
+            ],
+            'canBeDisabled keeps explicit true' => [
+                ['enabled' => true],
+                ['enabled' => true, 'foo' => 'baz'],
+                static fn () => $factory(static fn ($node) => $node->canBeDisabled()),
+            ],
+        ];
+    }
+
     public function testRequiresAtLeastOneElement()
     {
         $node = new ArrayNodeDefinition('root');
@@ -351,27 +437,6 @@ class ArrayNodeDefinitionTest extends TestCase
         $this->assertSame('1.1', $deprecation['version']);
     }
 
-    /**
-     * @group legacy
-     */
-    public function testSetDeprecatedWithoutPackageAndVersion()
-    {
-        $this->expectDeprecation('Since symfony/config 5.1: The signature of method "Symfony\Component\Config\Definition\Builder\NodeDefinition::setDeprecated()" requires 3 arguments: "string $package, string $version, string $message", not defining them is deprecated.');
-        $node = new ArrayNodeDefinition('root');
-        $node
-            ->children()
-            ->arrayNode('foo')->setDeprecated('The "%path%" node is deprecated.')->end()
-            ->end()
-        ;
-        $deprecatedNode = $node->getNode()->getChildren()['foo'];
-
-        $this->assertTrue($deprecatedNode->isDeprecated());
-        $deprecation = $deprecatedNode->getDeprecation($deprecatedNode->getName(), $deprecatedNode->getPath());
-        $this->assertSame('The "root.foo" node is deprecated.', $deprecation['message']);
-        $this->assertSame('', $deprecation['package']);
-        $this->assertSame('', $deprecation['version']);
-    }
-
     public function testCannotBeEmptyOnConcreteNode()
     {
         $this->expectException(InvalidDefinitionException::class);
@@ -464,7 +529,6 @@ class ArrayNodeDefinitionTest extends TestCase
     protected function getField(object $object, string $field)
     {
         $reflection = new \ReflectionProperty($object, $field);
-        $reflection->setAccessible(true);
 
         return $reflection->getValue($object);
     }
