@@ -2,24 +2,24 @@
 
 return [
     'Names' => [
-        'Africa/Abidjan' => 'ग्रीनविच मीन वक्तु (ابي جان)',
-        'Africa/Accra' => 'ग्रीनविच मीन वक्तु (ايڪرا)',
+        'Africa/Abidjan' => 'ग्रीनविच मीन वक़्तु (ابي جان)',
+        'Africa/Accra' => 'ग्रीनविच मीन वक़्तु (ايڪرا)',
         'Africa/Algiers' => 'मरकज़ी यूरोपी वक्त (الجيرز)',
-        'Africa/Bamako' => 'ग्रीनविच मीन वक्तु (باماڪو)',
-        'Africa/Banjul' => 'ग्रीनविच मीन वक्तु (بينجال)',
-        'Africa/Bissau' => 'ग्रीनविच मीन वक्तु (بسائو)',
+        'Africa/Bamako' => 'ग्रीनविच मीन वक़्तु (باماڪو)',
+        'Africa/Banjul' => 'ग्रीनविच मीन वक़्तु (بينجال)',
+        'Africa/Bissau' => 'ग्रीनविच मीन वक़्तु (بسائو)',
         'Africa/Cairo' => 'ओभरी यूरोपी वक्तु (قائرا)',
         'Africa/Casablanca' => 'उलहंदो यूरोपी वक्तु (ڪاسابلانڪا)',
         'Africa/Ceuta' => 'मरकज़ी यूरोपी वक्त (سيوٽا)',
-        'Africa/Conakry' => 'ग्रीनविच मीन वक्तु (ڪوناڪري)',
-        'Africa/Dakar' => 'ग्रीनविच मीन वक्तु (ڊاڪار)',
+        'Africa/Conakry' => 'ग्रीनविच मीन वक़्तु (ڪوناڪري)',
+        'Africa/Dakar' => 'ग्रीनविच मीन वक़्तु (ڊاڪار)',
         'Africa/El_Aaiun' => 'उलहंदो यूरोपी वक्तु (ال ايون)',
-        'Africa/Freetown' => 'ग्रीनविच मीन वक्तु (فري ٽائون)',
-        'Africa/Lome' => 'ग्रीनविच मीन वक्तु (لوم)',
-        'Africa/Monrovia' => 'ग्रीनविच मीन वक्तु (مونروویا)',
-        'Africa/Nouakchott' => 'ग्रीनविच मीन वक्तु (نواڪشوط)',
-        'Africa/Ouagadougou' => 'ग्रीनविच मीन वक्तु (آئوگو ڊائوگو)',
-        'Africa/Sao_Tome' => 'ग्रीनविच मीन वक्तु (سائو ٽوم)',
+        'Africa/Freetown' => 'ग्रीनविच मीन वक़्तु (فري ٽائون)',
+        'Africa/Lome' => 'ग्रीनविच मीन वक़्तु (لوم)',
+        'Africa/Monrovia' => 'ग्रीनविच मीन वक़्तु (مونروویا)',
+        'Africa/Nouakchott' => 'ग्रीनविच मीन वक़्तु (نواڪشوط)',
+        'Africa/Ouagadougou' => 'ग्रीनविच मीन वक़्तु (آئوگو ڊائوگو)',
+        'Africa/Sao_Tome' => 'ग्रीनविच मीन वक़्तु (سائو ٽوم)',
         'Africa/Tripoli' => 'ओभरी यूरोपी वक्तु (ٽرپولي)',
         'Africa/Tunis' => 'मरकज़ी यूरोपी वक्त (تيونس)',
         'America/Anguilla' => 'अटलांटिक वक्त (انگويلا)',
@@ -37,19 +37,22 @@ return [
         'America/Chihuahua' => 'मरकज़ी वक्त (چي هوا هوا)',
         'America/Ciudad_Juarez' => 'पहाड़ी वक्त (سوڊيڊ جوريز)',
         'America/Coral_Harbour' => 'ओभरी वक्त (اٽيڪوڪن)',
+        'America/Atikokan' => 'ओभरी वक्त (اٽيڪوڪن)',
         'America/Costa_Rica' => 'मरकज़ी वक्त (ڪوسٽا ريڪا)',
         'America/Creston' => 'पहाड़ी वक्त (ڪريسٽن)',
         'America/Curacao' => 'अटलांटिक वक्त (ڪيوراسائو)',
-        'America/Danmarkshavn' => 'ग्रीनविच मीन वक्तु (ڊينمارڪ شون)',
+        'America/Danmarkshavn' => 'ग्रीनविच मीन वक़्तु (ڊينمارڪ شون)',
         'America/Dawson_Creek' => 'पहाड़ी वक्त (ڊاوسن ڪريڪ)',
         'America/Denver' => 'पहाड़ी वक्त (ڊينور)',
         'America/Detroit' => 'ओभरी वक्त (ڊيٽرائيٽ)',
         'America/Dominica' => 'अटलांटिक वक्त (ڊومينيڪا)',
         'America/Edmonton' => 'पहाड़ी वक्त (ايڊمونٽن)',
-        'America/Eirunepe' => 'ब्राज़ील वक्त (ايرونيپ)',
+        'America/Eirunepe' => 'ब्राज़ील वक़्तु (ايرونيپ)',
         'America/El_Salvador' => 'मरकज़ी वक्त (ايل سلواڊور)',
         'America/Fort_Nelson' => 'पहाड़ी वक्त (فورٽ نيلسن)',
         'America/Glace_Bay' => 'अटलांटिक वक्त (گليس بي)',
+        'America/Godthab' => 'گرين لينڊ वक़्तु (نيوڪ)',
+        'America/Nuuk' => 'گرين لينڊ वक़्तु (نيوڪ)',
         'America/Goose_Bay' => 'अटलांटिक वक्त (گوز بي)',
         'America/Grand_Turk' => 'ओभरी वक्त (گرانڊ ترڪ)',
         'America/Grenada' => 'अटलांटिक वक्त (گريناڊا)',
@@ -64,6 +67,7 @@ return [
         'America/Indiana/Vincennes' => 'ओभरी वक्त (ونسینیز، انڊیانا)',
         'America/Indiana/Winamac' => 'ओभरी वक्त (ويناميڪ، انڊيانا)',
         'America/Indianapolis' => 'ओभरी वक्त (انڊيانا پولس)',
+        'America/Indiana/Indianapolis' => 'ओभरी वक्त (انڊيانا پولس)',
         'America/Inuvik' => 'पहाड़ी वक्त (انووڪ)',
         'America/Iqaluit' => 'ओभरी वक्त (اڪالوئٽ)',
         'America/Jamaica' => 'ओभरी वक्त (جمائڪا)',
@@ -71,6 +75,7 @@ return [
         'America/Kralendijk' => 'अटलांटिक वक्त (ڪرالينڊڪ)',
         'America/Los_Angeles' => 'पेसिफिक वक्त (لاس اينجلس)',
         'America/Louisville' => 'ओभरी वक्त (لوئي ويل)',
+        'America/Kentucky/Louisville' => 'ओभरी वक्त (لوئي ويل)',
         'America/Lower_Princes' => 'अटलांटिक वक्त (لوئر پرنسز ڪوارٽر)',
         'America/Managua' => 'मरकज़ी वक्त (ماناگوا)',
         'America/Marigot' => 'अटलांटिक वक्त (ميريگوٽ)',
@@ -96,8 +101,9 @@ return [
         'America/Rankin_Inlet' => 'मरकज़ी वक्त (رينڪن انليٽ)',
         'America/Regina' => 'मरकज़ी वक्त (ریجینا)',
         'America/Resolute' => 'मरकज़ी वक्त (ريزوليوٽ)',
-        'America/Rio_Branco' => 'ब्राज़ील वक्त (ريو برانڪو)',
+        'America/Rio_Branco' => 'ब्राज़ील वक़्तु (ريو برانڪو)',
         'America/Santo_Domingo' => 'अटलांटिक वक्त (سينٽو ڊومينگو)',
+        'America/Scoresbysund' => 'گرين لينڊ वक़्तु (اٽوڪورٽومائٽ)',
         'America/St_Barthelemy' => 'अटलांटिक वक्त (سينٽ برٿليمي)',
         'America/St_Kitts' => 'अटलांटिक वक्त (سينٽ ڪٽس)',
         'America/St_Lucia' => 'अटलांटिक वक्त (سينٽ لوسيا)',
@@ -111,33 +117,31 @@ return [
         'America/Tortola' => 'अटलांटिक वक्त (ٽورٽولا)',
         'America/Vancouver' => 'पेसिफिक वक्त (وينڪوور)',
         'America/Winnipeg' => 'मरकज़ी वक्त (وني پيگ)',
-        'Antarctica/Casey' => 'انٽارڪٽيڪا वक्त (ڪيسي)',
-        'Antarctica/Troll' => 'ग्रीनविच मीन वक्तु (ٽرول)',
+        'Antarctica/Troll' => 'ग्रीनविच मीन वक़्तु (ٽرول)',
         'Arctic/Longyearbyen' => 'मरकज़ी यूरोपी वक्त (لانگ ائيربن)',
         'Asia/Amman' => 'ओभरी यूरोपी वक्तु (امان)',
-        'Asia/Anadyr' => 'रशिया वक्त (انيدر)',
-        'Asia/Barnaul' => 'रशिया वक्त (برنل)',
+        'Asia/Anadyr' => 'रशिया वक़्तु (انيدر)',
         'Asia/Beirut' => 'ओभरी यूरोपी वक्तु (بيروت)',
         'Asia/Damascus' => 'ओभरी यूरोपी वक्तु (دمشق)',
         'Asia/Famagusta' => 'ओभरी यूरोपी वक्तु (فاماگوستا)',
         'Asia/Gaza' => 'ओभरी यूरोपी वक्तु (غزه)',
         'Asia/Hebron' => 'ओभरी यूरोपी वक्तु (هيبرون)',
-        'Asia/Kamchatka' => 'रशिया वक्त (ڪمچاسڪي)',
+        'Asia/Kamchatka' => 'रशिया वक़्तु (ڪمچاسڪي)',
         'Asia/Nicosia' => 'ओभरी यूरोपी वक्तु (نيڪوسيا)',
-        'Asia/Tomsk' => 'रशिया वक्त (تمسڪ)',
-        'Asia/Urumqi' => 'चीन वक्त (يورمڪي)',
+        'Asia/Urumqi' => 'चीन वक़्तु (يورمڪي)',
+        'Atlantic/Azores' => 'वक़्तु (ازورز)',
         'Atlantic/Bermuda' => 'अटलांटिक वक्त (برمودا)',
         'Atlantic/Canary' => 'उलहंदो यूरोपी वक्तु (ڪينري)',
         'Atlantic/Faeroe' => 'उलहंदो यूरोपी वक्तु (فيرو)',
+        'Atlantic/Faroe' => 'उलहंदो यूरोपी वक्तु (فيرو)',
         'Atlantic/Madeira' => 'उलहंदो यूरोपी वक्तु (ماڊيرا)',
-        'Atlantic/Reykjavik' => 'ग्रीनविच मीन वक्तु (ريڪيوڪ)',
-        'Atlantic/St_Helena' => 'ग्रीनविच मीन वक्तु (سينٽ هيلينا)',
-        'CST6CDT' => 'मरकज़ी वक्त',
-        'EST5EDT' => 'ओभरी वक्त',
-        'Etc/GMT' => 'ग्रीनविच मीन वक्तु',
+        'Atlantic/Reykjavik' => 'ग्रीनविच मीन वक़्तु (ريڪيوڪ)',
+        'Atlantic/St_Helena' => 'ग्रीनविच मीन वक़्तु (سينٽ هيلينا)',
+        'Etc/GMT' => 'ग्रीनविच मीन वक़्तु',
         'Etc/UTC' => 'गदि॒यल आलमी वक्तु',
         'Europe/Amsterdam' => 'मरकज़ी यूरोपी वक्त (ايمسٽرڊيم)',
         'Europe/Andorra' => 'मरकज़ी यूरोपी वक्त (اندورا)',
+        'Europe/Astrakhan' => 'रशिया वक़्तु (آستراخان)',
         'Europe/Athens' => 'ओभरी यूरोपी वक्तु (ايٿنز)',
         'Europe/Belgrade' => 'मरकज़ी यूरोपी वक्त (بلغراد)',
         'Europe/Berlin' => 'मरकज़ी यूरोपी वक्त (برلن)',
@@ -148,19 +152,19 @@ return [
         'Europe/Busingen' => 'मरकज़ी यूरोपी वक्त (بزيجين)',
         'Europe/Chisinau' => 'ओभरी यूरोपी वक्तु (چسينائو)',
         'Europe/Copenhagen' => 'मरकज़ी यूरोपी वक्त (ڪوپن هيگن)',
-        'Europe/Dublin' => 'ग्रीनविच मीन वक्तु (ڊبلن)',
+        'Europe/Dublin' => 'آئرلينڊ वक़्तु (ڊبلن)',
         'Europe/Gibraltar' => 'मरकज़ी यूरोपी वक्त (جبرالٽر)',
-        'Europe/Guernsey' => 'ग्रीनविच मीन वक्तु (گرنزي)',
+        'Europe/Guernsey' => 'ग्रीनविच मीन वक़्तु (گرنزي)',
         'Europe/Helsinki' => 'ओभरी यूरोपी वक्तु (هيلسنڪي)',
-        'Europe/Isle_of_Man' => 'ग्रीनविच मीन वक्तु (آئيزل آف مين)',
-        'Europe/Istanbul' => 'ترڪييي वक्त (استنبول)',
-        'Europe/Jersey' => 'ग्रीनविच मीन वक्तु (جرسي)',
+        'Europe/Isle_of_Man' => 'ग्रीनविच मीन वक़्तु (آئيزل آف مين)',
+        'Europe/Istanbul' => 'ترڪييي वक़्तु (استنبول)',
+        'Europe/Jersey' => 'ग्रीनविच मीन वक़्तु (جرسي)',
         'Europe/Kaliningrad' => 'ओभरी यूरोपी वक्तु (ڪلينن گراڊ)',
         'Europe/Kiev' => 'ओभरी यूरोपी वक्तु (ڪِيو)',
-        'Europe/Kirov' => 'रशिया वक्त (ڪيروف)',
+        'Europe/Kyiv' => 'ओभरी यूरोपी वक्तु (ڪِيو)',
         'Europe/Lisbon' => 'उलहंदो यूरोपी वक्तु (لسبن)',
         'Europe/Ljubljana' => 'मरकज़ी यूरोपी वक्त (لبليانا)',
-        'Europe/London' => 'ग्रीनविच मीन वक्तु (لنڊن)',
+        'Europe/London' => 'ग्रीनविच मीन वक़्तु (لنڊن)',
         'Europe/Luxembourg' => 'मरकज़ी यूरोपी वक्त (لگزمبرگ)',
         'Europe/Madrid' => 'मरकज़ी यूरोपी वक्त (ميڊرڊ)',
         'Europe/Malta' => 'मरकज़ी यूरोपी वक्त (مالٽا)',
@@ -172,23 +176,23 @@ return [
         'Europe/Prague' => 'मरकज़ी यूरोपी वक्त (پراگ)',
         'Europe/Riga' => 'ओभरी यूरोपी वक्तु (رگا)',
         'Europe/Rome' => 'मरकज़ी यूरोपी वक्त (روم)',
-        'Europe/Samara' => 'रशिया वक्त (سمارا)',
+        'Europe/Samara' => 'रशिया वक़्तु (سمارا)',
         'Europe/San_Marino' => 'मरकज़ी यूरोपी वक्त (سين مرينو)',
         'Europe/Sarajevo' => 'मरकज़ी यूरोपी वक्त (سراجیوو)',
+        'Europe/Saratov' => 'रशिया वक़्तु (سراتو)',
         'Europe/Skopje' => 'मरकज़ी यूरोपी वक्त (اسڪوپي)',
         'Europe/Sofia' => 'ओभरी यूरोपी वक्तु (سوفيا)',
         'Europe/Stockholm' => 'मरकज़ी यूरोपी वक्त (اسٽاڪ هوم)',
         'Europe/Tallinn' => 'ओभरी यूरोपी वक्तु (ٽالن)',
         'Europe/Tirane' => 'मरकज़ी यूरोपी वक्त (تراني)',
+        'Europe/Ulyanovsk' => 'रशिया वक़्तु (اليانوسڪ)',
         'Europe/Vaduz' => 'मरकज़ी यूरोपी वक्त (وڊوز)',
         'Europe/Vatican' => 'मरकज़ी यूरोपी वक्त (وئٽيڪن)',
-        'Europe/Vienna' => 'मरकज़ी यूरोपी वक्त (وينا)',
+        'Europe/Vienna' => 'मरकज़ी यूरोपी वक्त (ويئينا)',
         'Europe/Vilnius' => 'ओभरी यूरोपी वक्तु (ويلنيس)',
         'Europe/Warsaw' => 'मरकज़ी यूरोपी वक्त (وارسا)',
         'Europe/Zagreb' => 'मरकज़ी यूरोपी वक्त (زغرب)',
         'Europe/Zurich' => 'मरकज़ी यूरोपी वक्त (زيورخ)',
-        'MST7MDT' => 'पहाड़ी वक्त',
-        'PST8PDT' => 'पेसिफिक वक्त',
     ],
     'Meta' => [
         'GmtFormat' => 'जीएमटी%s',
